@@ -15,8 +15,7 @@ quote_collapse <- function(x, quote = "`", collapse = ", ") {
 
 abort_default <- function(x, fn) {
   cls <- quote_collapse(class(x))
-  msg <- paste0("No implementation of `", fn, "()` for object of class ", cls, ".")
-  abort(msg)
+  cli::cli_abort("No implementation of {.fn {fn}} for {.obj_type_friendly {cls}}.")
 }
 
 # Check if a class_pred object came from an ordered factor
