@@ -24,13 +24,14 @@ test_that("Binary breaks functions work", {
   )
 
   brks_configs <-
-    bin_with_configs() %>% cal_plot_breaks(truth = Class, estimate = .pred_good)
+    bin_with_configs() |> cal_plot_breaks(truth = Class, estimate = .pred_good)
   expect_true(has_facet(brks_configs))
 })
 
 test_that("Binary breaks functions work with group argument", {
-  res <- segment_logistic %>%
-    dplyr::mutate(id = dplyr::row_number() %% 2) %>%
+  skip_if_not_installed("ggplot2", minimum_version = "3.5.2.9000")
+  res <- segment_logistic |>
+    dplyr::mutate(id = dplyr::row_number() %% 2) |>
     cal_plot_breaks(Class, .pred_good, .by = id)
 
   expect_s3_class(res, "ggplot")
@@ -58,20 +59,20 @@ test_that("Binary breaks functions work with group argument", {
   )
   expect_equal(
     res$labels,
-    list(x = "Bin Midpoint", y = "Event Rate", colour = "id", fill = "id",
-         intercept = "intercept", slope = "slope", ymin = "lower",
-         ymax = "upper")
+    list(x = "Bin Midpoint", y = "Event Rate")
   )
   expect_equal(length(res$layers), 4)
 
   expect_snapshot_error(
-    segment_logistic %>%
-      dplyr::mutate(group1 = 1, group2 = 2) %>%
+    segment_logistic |>
+      dplyr::mutate(group1 = 1, group2 = 2) |>
       cal_plot_breaks(Class, .pred_good, .by = c(group1, group2))
   )
 })
 
 test_that("Multi-class breaks functions work", {
+  skip_if_not_installed("modeldata")
+
   x10 <- .cal_table_breaks(species_probs, Species, dplyr::starts_with(".pred"))
 
   expect_equal(
@@ -104,13 +105,13 @@ test_that("Multi-class breaks functions work", {
   # multinomial outcome, binary logistic plots
 
   multi_configs_from_tune <-
-    testthat_cal_multiclass() %>% cal_plot_breaks()
+    testthat_cal_multiclass() |> cal_plot_breaks()
   expect_s3_class(multi_configs_from_tune, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_tune$facet, "FacetGrid"))
 
   multi_configs_from_df <-
-    mnl_with_configs() %>% cal_plot_breaks(truth = obs, estimate = c(VF:L))
+    mnl_with_configs() |> cal_plot_breaks(truth = obs, estimate = c(VF:L))
   expect_s3_class(multi_configs_from_df, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_df$facet, "FacetGrid"))
@@ -123,6 +124,8 @@ test_that("breaks plot function errors - grouped_df", {
 })
 
 test_that("Binary logistic functions work", {
+  skip_if_not_installed("modeldata")
+
   x20 <- .cal_table_logistic(segment_logistic, Class, .pred_good)
 
   model20 <- mgcv::gam(Class ~ s(.pred_good, k = 10),
@@ -146,9 +149,9 @@ test_that("Binary logistic functions work", {
   x22 <- .cal_table_logistic(testthat_cal_binary())
 
 
-  x22_1 <- testthat_cal_binary() %>%
-    tune::collect_predictions(summarize = TRUE) %>%
-    dplyr::group_by(.config) %>%
+  x22_1 <- testthat_cal_binary() |>
+    tune::collect_predictions(summarize = TRUE) |>
+    dplyr::group_by(.config) |>
     dplyr::group_map(~ {
       model <- mgcv::gam(
         class ~ s(.pred_class_1, k = 10),
@@ -160,7 +163,7 @@ test_that("Binary logistic functions work", {
         type = "response"
       )
       1 - preds
-    }) %>%
+    }) |>
     purrr::reduce(c)
 
   expect_equal(sd(x22$prob), sd(x22_1), tolerance = 0.000001)
@@ -196,29 +199,30 @@ test_that("Binary logistic functions work", {
   )
 
   lgst_configs <-
-    bin_with_configs() %>% cal_plot_logistic(truth = Class, estimate = .pred_good)
+    bin_with_configs() |> cal_plot_logistic(truth = Class, estimate = .pred_good)
   expect_true(has_facet(lgst_configs))
 
   # ------------------------------------------------------------------------------
   # multinomial outcome, binary logistic plots
 
   multi_configs_from_tune <-
-    testthat_cal_multiclass() %>% cal_plot_logistic(smooth = FALSE)
+    testthat_cal_multiclass() |> cal_plot_logistic(smooth = FALSE)
   expect_s3_class(multi_configs_from_tune, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_tune$facet, "FacetGrid"))
 
 
   multi_configs_from_df <-
-    mnl_with_configs() %>% cal_plot_logistic(truth = obs, estimate = c(VF:L))
+    mnl_with_configs() |> cal_plot_logistic(truth = obs, estimate = c(VF:L))
   expect_s3_class(multi_configs_from_df, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_df$facet, "FacetGrid"))
 })
 
 test_that("Binary logistic functions work with group argument", {
-  res <- segment_logistic %>%
-    dplyr::mutate(id = dplyr::row_number() %% 2) %>%
+  skip_if_not_installed("ggplot2", minimum_version = "3.5.2.9000")
+  res <- segment_logistic |>
+    dplyr::mutate(id = dplyr::row_number() %% 2) |>
     cal_plot_logistic(Class, .pred_good, .by = id)
 
   expect_s3_class(
@@ -251,20 +255,18 @@ test_that("Binary logistic functions work with group argument", {
   )
   expect_equal(
     res$labels,
-    list(x = "Probability", y = "Predicted Event Rate", colour = "id",
-         fill = "id", intercept = "intercept", slope = "slope", ymin = "lower",
-         ymax = "upper")
+    list(x = "Probability", y = "Predicted Event Rate")
   )
   expect_equal(length(res$layers), 3)
 
   expect_snapshot_error(
-    segment_logistic %>%
-      dplyr::mutate(group1 = 1, group2 = 2) %>%
+    segment_logistic |>
+      dplyr::mutate(group1 = 1, group2 = 2) |>
       cal_plot_logistic(Class, .pred_good, .by = c(group1, group2))
   )
 
   lgst_configs <-
-    bin_with_configs() %>% cal_plot_logistic(truth = Class, estimate = .pred_good)
+    bin_with_configs() |> cal_plot_logistic(truth = Class, estimate = .pred_good)
   expect_true(has_facet(lgst_configs))
 })
 
@@ -275,6 +277,8 @@ test_that("logistic plot function errors - grouped_df", {
 })
 
 test_that("Binary windowed functions work", {
+  skip_if_not_installed("modeldata")
+
   x30 <- .cal_table_windowed(
     segment_logistic,
     truth = Class,
@@ -283,7 +287,7 @@ test_that("Binary windowed functions work", {
     window_size = 0.10
   )
 
-  x30_1 <- segment_logistic %>%
+  x30_1 <- segment_logistic |>
     dplyr::mutate(x = dplyr::case_when(
       .pred_good <= 0.05 ~ 1,
       .pred_good >= 0.06 & .pred_good <= 0.16 ~ 2,
@@ -295,8 +299,8 @@ test_that("Binary windowed functions work", {
       .pred_good >= 0.72 & .pred_good <= 0.82 ~ 8,
       .pred_good >= 0.83 & .pred_good <= 0.93 ~ 9,
       .pred_good >= 0.94 & .pred_good <= 1 ~ 10,
-    )) %>%
-    dplyr::filter(!is.na(x)) %>%
+    )) |>
+    dplyr::filter(!is.na(x)) |>
     dplyr::count(x)
 
   expect_equal(
@@ -315,8 +319,8 @@ test_that("Binary windowed functions work", {
     window_size = 0.10
   )
 
-  x32_1 <- testthat_cal_binary() %>%
-    tune::collect_predictions(summarize = TRUE) %>%
+  x32_1 <- testthat_cal_binary() |>
+    tune::collect_predictions(summarize = TRUE) |>
     dplyr::mutate(x = dplyr::case_when(
       .pred_class_1 <= 0.05 ~ 1,
       .pred_class_1 >= 0.06 & .pred_class_1 <= 0.16 ~ 2,
@@ -328,8 +332,8 @@ test_that("Binary windowed functions work", {
       .pred_class_1 >= 0.72 & .pred_class_1 <= 0.82 ~ 8,
       .pred_class_1 >= 0.83 & .pred_class_1 <= 0.93 ~ 9,
       .pred_class_1 >= 0.94 & .pred_class_1 <= 1 ~ 10,
-    )) %>%
-    dplyr::filter(!is.na(x)) %>%
+    )) |>
+    dplyr::filter(!is.na(x)) |>
     dplyr::count(.config, x)
 
   expect_equal(
@@ -343,7 +347,7 @@ test_that("Binary windowed functions work", {
   expect_true(has_facet(x33))
 
   win_configs <-
-    bin_with_configs() %>% cal_plot_windowed(truth = Class, estimate = .pred_good)
+    bin_with_configs() |> cal_plot_windowed(truth = Class, estimate = .pred_good)
   expect_true(has_facet(win_configs))
 
 
@@ -351,14 +355,14 @@ test_that("Binary windowed functions work", {
   # multinomial outcome, binary windowed plots
 
   multi_configs_from_tune <-
-    testthat_cal_multiclass() %>% cal_plot_windowed()
+    testthat_cal_multiclass() |> cal_plot_windowed()
   expect_s3_class(multi_configs_from_tune, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_tune$facet, "FacetGrid"))
 
 
   multi_configs_from_df <-
-    mnl_with_configs() %>% cal_plot_windowed(truth = obs, estimate = c(VF:L))
+    mnl_with_configs() |> cal_plot_windowed(truth = obs, estimate = c(VF:L))
   expect_s3_class(multi_configs_from_df, "ggplot")
   # should be faceted by .config and class
   expect_true(inherits(multi_configs_from_df$facet, "FacetGrid"))
@@ -384,10 +388,10 @@ test_that("Event level handling works", {
 
 
 test_that("Groups are respected", {
-  preds <- segment_logistic %>%
-    dplyr::mutate(source = "logistic") %>%
-    dplyr::bind_rows(segment_naive_bayes) %>%
-    dplyr::mutate(source = ifelse(is.na(source), "nb", source)) %>%
+  preds <- segment_logistic |>
+    dplyr::mutate(source = "logistic") |>
+    dplyr::bind_rows(segment_naive_bayes) |>
+    dplyr::mutate(source = ifelse(is.na(source), "nb", source)) |>
     dplyr::group_by(source)
 
   x40 <- .cal_table_breaks(preds, Class, .pred_good)
@@ -419,8 +423,8 @@ test_that("Groupings that may not match work", {
     dplyr::mutate(segment_logistic, .pred_good = preds, source = "glm")
   )
 
-  x50 <- combined %>%
-    dplyr::group_by(source) %>%
+  x50 <- combined |>
+    dplyr::group_by(source) |>
     .cal_table_breaks(Class, .pred_good)
 
   expect_equal(
@@ -428,8 +432,8 @@ test_that("Groupings that may not match work", {
     seq(0.05, 0.95, by = 0.10)
   )
 
-  x51 <- combined %>%
-    dplyr::group_by(source) %>%
+  x51 <- combined |>
+    dplyr::group_by(source) |>
     .cal_table_windowed(
       truth = Class,
       estimate = .pred_good,
@@ -437,7 +441,7 @@ test_that("Groupings that may not match work", {
       window_size = 0.10
     )
 
-  x51_1 <- combined %>%
+  x51_1 <- combined |>
     dplyr::mutate(x = dplyr::case_when(
       .pred_good <= 0.05 ~ 1,
       .pred_good >= 0.06 & .pred_good <= 0.16 ~ 2,
@@ -449,8 +453,8 @@ test_that("Groupings that may not match work", {
       .pred_good >= 0.72 & .pred_good <= 0.82 ~ 8,
       .pred_good >= 0.83 & .pred_good <= 0.93 ~ 9,
       .pred_good >= 0.94 & .pred_good <= 1 ~ 10,
-    )) %>%
-    dplyr::filter(!is.na(x)) %>%
+    )) |>
+    dplyr::filter(!is.na(x)) |>
     dplyr::count(source, x)
 
   expect_equal(
@@ -463,7 +467,7 @@ test_that("Numeric groups are supported", {
   grp_df <- segment_logistic
   grp_df$num_group <- rep(c(1, 2), times = 505)
 
-  p <- grp_df %>%
+  p <- grp_df |>
     cal_plot_breaks(Class, .pred_good, .by = num_group)
 
   expect_s3_class(p, "ggplot")
@@ -482,6 +486,7 @@ test_that("Some general exceptions", {
 # ------------------------------------------------------------------------------
 
 test_that("regression functions work", {
+  skip_if_not_installed("ggplot2", minimum_version = "3.5.2.9000")
   skip_if(R.version[["arch"]] != "aarch64") # see note below
 
   obj <- testthat_cal_reg()
@@ -507,8 +512,7 @@ test_that("regression functions work", {
 
   expect_equal(
     res$labels,
-    list(x = "Observed", y = "Predicted", colour = "colour", fill = "fill",
-         intercept = "intercept", slope = "slope")
+    list(x = "Observed", y = "Predicted")
   )
   expect_equal(length(res$layers), 3)
 
@@ -534,8 +538,7 @@ test_that("regression functions work", {
 
   expect_equal(
     res$labels,
-    list(x = "Observed", y = "Predicted", colour = "colour", fill = "fill",
-         intercept = "intercept", slope = "slope")
+    list(x = "Observed", y = "Predicted")
   )
   expect_equal(length(res$layers), 3)
 
@@ -564,8 +567,7 @@ test_that("regression functions work", {
 
   expect_equal(
     res$labels,
-    list(x = "Observed", y = "Predicted", colour = "colour", fill = "fill",
-         intercept = "intercept", slope = "slope")
+    list(x = "Observed", y = "Predicted")
   )
   expect_equal(length(res$layers), 3)
 
@@ -594,8 +596,7 @@ test_that("regression functions work", {
 
   expect_equal(
     res$labels,
-    list(x = "Observed", y = "Predicted", colour = "colour", fill = "fill",
-         intercept = "intercept", slope = "slope")
+    list(x = "Observed", y = "Predicted")
   )
   expect_equal(length(res$layers), 3)
 
@@ -622,8 +623,7 @@ test_that("regression functions work", {
 
   expect_equal(
     res$labels,
-    list(x = "Observed", y = "Predicted", colour = "colour", fill = "fill",
-         intercept = "intercept", slope = "slope")
+    list(x = "Observed", y = "Predicted")
   )
   expect_equal(length(res$layers), 3)
 
@@ -673,3 +673,10 @@ test_that("don't facet if there is only one .config", {
   expect_null(res_regression$data[[".config"]])
   expect_s3_class(res_regression, "ggplot")
 })
+
+test_that("custom names for cal_plot_breaks()", {
+  data(segment_logistic)
+  segment_logistic_1 <- dplyr::rename(segment_logistic, good_prob = .pred_good)
+  p <- cal_plot_breaks(segment_logistic_1, Class, good_prob)
+  expect_s3_class(p, "ggplot")
+})
